"""
Main entry point for running the MCP Inflectra Spira server as a module.

This allows running the server with:
    python -m mcp_server_spira
"""
from mcp_server_spira.server import main

if __name__ == "__main__":
    main()